@@ -78,24 +78,25 @@ class StreamLiker(YSL):
 
     def is_streaming(self):
 
-        try:
-            ##### Status Code
-            print('Checking for streams...')
-            print()
+        ##### Status Code
+        print('Checking for streams...')
+        print()
 
-            for name in self.channels.keys():
-                channel_url = 'https://www.youtube.com/channel/' + self.channels[name]
-                response = requests.get(channel_url).text
-                stream_active = '{"text":" watching"}' in response
-                if stream_active:
-                    self.currently_streaming[name] = channel_url
-                    self.number_of_active_streams += 1
-                    print(f"{name} is currently streaming.")
+        for name in self.channels.keys():
+            print(name, end=" - ")
+            channel_url = 'https://www.youtube.com/channel/' + self.channels[name]
+            response = requests.get(channel_url).text
+            stream_active = '{"text":" watching"}' in response
+            print("is ", end="")
+            if stream_active:
+                self.currently_streaming[name] = channel_url
+                self.number_of_active_streams += 1
+                print("currently streaming.")
+            else:
+                print("not streaming.")
 
-            self.stream_data['No. of active streams'] = self.number_of_active_streams
-            print()
-        except:
-            assert False, "is_streamingError: MaxConnection Pool. Restart the program"
+        self.stream_data['No. of active streams'] = self.number_of_active_streams
+        print()
 
     def like_videos(self):
 
@@ -212,7 +213,10 @@ class StreamLiker(YSL):
     def append_data_on_db(self, user, host, passwd, database, table_name):
         tel = self.stream_data["Time elapsed"]
         nas = self.stream_data["No. of active streams"]
-        nls = self.stream_data["No. of to-be-liked streams"]
+        if "No. of to-be-liked streams" not in self.stream_data.keys():
+            nls = 0
+        else:
+            nls = self.stream_data["No. of to-be-liked streams"]
         ts = self.stream_data["Time Started"]
         te = self.stream_data["Time Ended"]
         d = self.date
@@ -246,16 +250,14 @@ class StreamLiker(YSL):
         my_cursor.execute(query + "VALUES(%s,%s,%s,%s,%s,%s,%s)", (tel, nas, nls, ts, te, d, ver))
         db.commit()
 
-    def start_liking_with_data(self, user, host, passwd, db, table_name, my_dir):
-        try:
-            self.get_start_time()
-            self.is_streaming()
-            self.like_videos()
-            self.get_end_time()
-            self.append_data_on_file(my_dir)
-            self.append_data_on_db(user, host, passwd, db, table_name)
-        except:
-            self.driver_quit()
+    def start_liking_with_data(self, user, host, passwd, db, table_name, my_dir, path, options = None):
+        self.get_start_time()
+        self.is_streaming()
+        self.config_driver(path, options)
+        self.like_videos()
+        self.get_end_time()
+        self.append_data_on_file(my_dir)
+        self.append_data_on_db(user, host, passwd, db, table_name)
 
     def config_driver(self, path, args=None):
         try:
